==> cherokee_0.5.5.dfsg.orig.tar.gz: cherokee-0.5.5.dfsg/cherokee/handler_redir.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001-2006 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef CHEROKEE_HANDLER_REDIR_H
#define CHEROKEE_HANDLER_REDIR_H

#include "common.h"
#include "handler.h"
#include "module_loader.h"
#include "list.h"

typedef struct {
	cherokee_handler_t    handler;

	char                 *target_url;
	int                   target_url_len;

	list_t               *regex_list_ref;
	void                 *regex_list_cre;

	cherokee_boolean_t    use_previous_match;

} cherokee_handler_redir_t;

#define REHANDLER(x)  ((cherokee_handler_redir_t *)(x))


void MODULE_INIT(redir) (cherokee_module_loader_t *loader);
ret_t cherokee_handler_redir_new (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *properties);

/* virtual methods implementation
 */
ret_t cherokee_handler_redir_init        (cherokee_handler_redir_t *rehdl);
ret_t cherokee_handler_redir_free        (cherokee_handler_redir_t *rehdl);
ret_t cherokee_handler_redir_add_headers (cherokee_handler_redir_t *rehdl, cherokee_buffer_t *buffer);

#endif /* CHEROKEE_HANDLER_REDIR_H */

==> cherokee-0.6.0b700.tar.gz: cherokee-0.6.0b700/cherokee/handler_redir.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001-2007 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef CHEROKEE_HANDLER_REDIR_H
#define CHEROKEE_HANDLER_REDIR_H

#include "common.h"
#include "handler.h"
#include "plugin_loader.h"
#include "list.h"


/* Data types
 */
typedef struct {
	cherokee_module_props_t base;
	cherokee_buffer_t        url;
	cherokee_list_t          regex_list;
} cherokee_handler_redir_props_t;

typedef struct {
	cherokee_handler_t       handler;
	cherokee_boolean_t       use_previous_match;
} cherokee_handler_redir_t;

#define PROP_REDIR(x)      ((cherokee_handler_redir_props_t *)(x))
#define HDL_REDIR(x)       ((cherokee_handler_redir_t *)(x))
#define HDL_REDIR_PROPS(x) (PROP_REDIR(MODULE(x)->props))


/* Library init function
 */
void  PLUGIN_INIT_NAME(redir)    (cherokee_plugin_loader_t *loader);
ret_t cherokee_handler_redir_new (cherokee_handler_t **hdl, void *cnt, cherokee_module_props_t *props);

/* virtual methods implementation
 */
ret_t cherokee_handler_redir_init        (cherokee_handler_redir_t *rehdl);
ret_t cherokee_handler_redir_free        (cherokee_handler_redir_t *rehdl);
ret_t cherokee_handler_redir_add_headers (cherokee_handler_redir_t *rehdl, cherokee_buffer_t *buffer);

#endif /* CHEROKEE_HANDLER_REDIR_H */
